==> gd32f1-0.2.1.crate: gd32f1-0.2.1/src/gd32f150/timer1/ch0cv.rs <==
#[doc = "Register `CH0CV` reader"]
pub struct R(crate::R<CH0CV_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH0CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<CH0CV_SPEC>> for R {
    fn from(reader: crate::R<CH0CV_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH0CV` writer"]
pub struct W(crate::W<CH0CV_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH0CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<CH0CV_SPEC>> for W {
    fn from(writer: crate::W<CH0CV_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CH0VAL` reader - Capture or compare value of channel 0"]
pub struct CH0VAL_R(crate::FieldReader<u32, u32>);
impl CH0VAL_R {
    pub(crate) fn new(bits: u32) -> Self {
        CH0VAL_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CH0VAL_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CH0VAL` writer - Capture or compare value of channel 0"]
pub struct CH0VAL_W<'a> {
    w: &'a mut W,
}
impl<'a> CH0VAL_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Capture or compare value of channel 0"]
    #[inline(always)]
    pub fn ch0val(&self) -> CH0VAL_R {
        CH0VAL_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Capture or compare value of channel 0"]
    #[inline(always)]
    pub fn ch0val(&mut self) -> CH0VAL_W {
        CH0VAL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Channel 0 capture/compare value register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch0cv](index.html) module"]
pub struct CH0CV_SPEC;
impl crate::RegisterSpec for CH0CV_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [ch0cv::R](R) reader structure"]
impl crate::Readable for CH0CV_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch0cv::W](W) writer structure"]
impl crate::Writable for CH0CV_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH0CV to value 0"]
impl crate::Resettable for CH0CV_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f150/timer1/ch0cv.rs <==
#[doc = "Register `CH0CV` reader"]
pub struct R(crate::R<CH0CV_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<CH0CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<CH0CV_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<CH0CV_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `CH0CV` writer"]
pub struct W(crate::W<CH0CV_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<CH0CV_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<CH0CV_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<CH0CV_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `CH0VAL` reader - Capture or compare value of channel 0"]
pub struct CH0VAL_R(crate::FieldReader<u32, u32>);
impl CH0VAL_R {
    pub(crate) fn new(bits: u32) -> Self {
        CH0VAL_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for CH0VAL_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `CH0VAL` writer - Capture or compare value of channel 0"]
pub struct CH0VAL_W<'a> {
    w: &'a mut W,
}
impl<'a> CH0VAL_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bits(self, value: u32) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xffff_ffff) | (value as u32 & 0xffff_ffff);
        self.w
    }
}
impl R {
    #[doc = "Bits 0:31 - Capture or compare value of channel 0"]
    #[inline(always)]
    pub fn ch0val(&self) -> CH0VAL_R {
        CH0VAL_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
impl W {
    #[doc = "Bits 0:31 - Capture or compare value of channel 0"]
    #[inline(always)]
    pub fn ch0val(&mut self) -> CH0VAL_W {
        CH0VAL_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Channel 0 capture/compare value register\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [ch0cv](index.html) module"]
pub struct CH0CV_SPEC;
impl crate::RegisterSpec for CH0CV_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [ch0cv::R](R) reader structure"]
impl crate::Readable for CH0CV_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [ch0cv::W](W) writer structure"]
impl crate::Writable for CH0CV_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets CH0CV to value 0"]
impl crate::Resettable for CH0CV_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
